@@ -86,6 +86,10 @@ class AsyncConsumerBase(Loggable):
         # for higher consumer throughput
         self._prefetch_count = 1
 
+    @property
+    def consuming(self):
+        return self._consuming
+
     @classmethod
     def sanitize_url_for_display(cls, url: str) -> str:
         m: regex.Match = regex.match(
