@@ -6,6 +6,7 @@ from otel_extensions import (
 from contextlib import contextmanager
 import os
 import tempfile
+import logging
 
 telemetry_initialized = False
 
@@ -36,6 +37,7 @@ XBhoBcSg
 
 DEFAULT_SILABS_NET_CA_CERT_FILE = "/usr/local/share/ca-certificates/vault-ca-prod.crt"
 
+
 def get_or_make_ca_file() -> str:
     if os.path.isfile(DEFAULT_SILABS_NET_CA_CERT_FILE):
         return DEFAULT_SILABS_NET_CA_CERT_FILE
@@ -47,10 +49,14 @@ def get_or_make_ca_file() -> str:
             f.write(SILABS_NET_CA)
     return ca_file_path
 
+
 @contextmanager
 def setup_telemetry():
+    logging.getLogger("opentelemetry.util._time").setLevel(logging.ERROR)
     global telemetry_initialized
     if not telemetry_initialized:
+        if os.environ.get("OTEL_EXPORTER_OTLP_CERTIFICATE") is None:
+            os.environ["OTEL_EXPORTER_OTLP_CERTIFICATE"] = get_or_make_ca_file()
         options = TelemetryOptions(
             OTEL_SERVICE_NAME=SERVICE_NAME,
             OTEL_EXPORTER_OTLP_ENDPOINT=os.environ.get(
@@ -60,11 +66,8 @@ def setup_telemetry():
             OTEL_EXPORTER_OTLP_PROTOCOL=os.environ.get(
                 "OTEL_EXPORTER_OTLP_PROTOCOL", "http/protobuf"
             ),
-            OTEL_EXPORTER_OTLP_CERTIFICATE=os.environ.get(
-                "OTEL_EXPORTER_OTLP_CERTIFICATE", get_or_make_ca_file()
-            )
         )
-        #init_telemetry_provider(options)
+        init_telemetry_provider(options)
         telemetry_initialized = True
     yield
     flush_telemetry_data()
