@@ -4,6 +4,7 @@ from ubai_client.apis import SearchApi
 from ubai_client.models import ArtifactStorage
 from time import sleep
 from utf_queue_client.scripts import setup_telemetry
+from retry import retry
 
 
 @click.command()
@@ -11,7 +12,7 @@ from utf_queue_client.scripts import setup_telemetry
 @click.option("--extension", default=None, help="artifact extension, e.g. '.bin'")
 @click.option("--metadata", multiple=True, type=(str, str))
 @click.option(
-    "--retries", default=3, help="number of retries (in case of network-related issues)"
+    "--retries", default=6, help="number of retries (in case of network-related issues)"
 )
 def cli_entrypoint(
     name: Optional[str],
@@ -28,7 +29,7 @@ def cli(
     name: Optional[str],
     extension: Optional[str],
     metadata: Iterable[Tuple[str, str]],
-    retries: int = 3,
+    retries: int = 6,
 ):
     with setup_telemetry():
         search_api = SearchApi()
@@ -43,15 +44,12 @@ def cli(
         if extension is not None:
             search_opts.extension = extension
 
-        total_attempts = retries + 1
-        for try_index in range(total_attempts):
-            try:
-                search_results = search_api.find_all_artifacts(search_opts)
-                return [result.id for result in search_results]
-            except Exception:
-                if (try_index + 1) >= total_attempts:
-                    raise
-                sleep(10)
+        @retry(Exception, delay=3, backoff=2, max_delay=12, tries=retries + 1)
+        def retry_wrapper():
+            search_results = search_api.find_all_artifacts(search_opts)
+            return [result.id for result in search_results]
+
+        return retry_wrapper()
 
 
 if __name__ == "__main__":
